@@ -23,11 +23,38 @@ function d3graphscript(config = {
     .linkDistance((d) => config.distance > 0 ? config.distance : d.edge_weight)
     .size([width, height]);
 
+  // DRAGGING START
+  function dragstarted(d) {
+    d3.event.sourceEvent.stopPropagation();
+    d3.select(this).classed("dragging", true);
+  }
+
+  function dragged(d) {
+    d3.select(this).attr("cx", d.x = d3.event.x).attr("cy", d.y = d3.event.y);
+  }
+
+  function dragended(d) {
+    d3.select(this).classed("dragging", false);
+  }
+
+  var drag = force.drag()
+    .origin(function(d) { return d; })
+    .on("dragstart", dragstarted)
+    .on("drag", dragged)
+    .on("dragend", dragended);
+
+  // DRAGGING STOP
 
   //Append a SVG to the body of the html page. Assign this SVG as an object to svg
   var svg = d3.select("body").append("svg")
     .attr("width", width)
     .attr("height", height)
+    .call(d3.behavior.zoom().on("zoom", function () {
+      svg.attr("transform", "translate(" + d3.event.translate + ")" + " scale(" + d3.event.scale + ")")
+    }))
+    .on("dblclick.zoom", null)
+    .append("g")
+
   //.on("dblclick", threshold); // EXPLODE ALL CONNECTED POINTS
 
   graphRec = JSON.parse(JSON.stringify(graph));
@@ -55,7 +82,7 @@ function d3graphscript(config = {
     .data(graph.nodes)
     .enter().append("g")
     .attr("class", "node")
-    .call(force.drag)
+    .call(drag)
     .on('dblclick', connectedNodes); // HIGHLIGHT ON/OFF
 
   {{ CLICK_COMMENT }} node.on('click', color_on_click); // ON CLICK HANDLER
